@@ -34,16 +34,31 @@ from pyalmanac.lib import config as config
 from pyalmanac.lib import increments as increments
 
 
-def makePDF(fn, msg = ""):
-    command = 'pdflatex {}'.format(fn + ".tex")
-    os.system(command)
-    print("finished" + msg)
+def makePDF(args, fn, msg = ""):
+    command = 'pdflatex {}'.format(args + fn + ".tex")
+    if args == "":
+        os.system(command)
+        print("finished" + msg)
+    else:
+        returned_value = os.system(command)
+        if returned_value != 0:
+            if msg != "":
+                print("ERROR detected while" + msg)
+            else:
+                print("!!   ERROR detected while creating PDF file   !!")
+                print("!! Append '-v' or '-log' for more information !!")
+        else:
+            if msg != "":
+                print("finished" + msg)
+            else:
+                print("finished creating PDF")
     return
 
 def tidy_up(fn):
-    os.remove(fn + ".tex")
-    if os.path.isfile(fn + ".log"):
-        os.remove(fn + ".log")
+    if not keeptex: os.remove(fn + ".tex")
+    if not keeplog:
+        if os.path.isfile(fn + ".log"):
+            os.remove(fn + ".log")
     if os.path.isfile(fn + ".aux"):
         os.remove(fn + ".aux")
     return
@@ -53,6 +68,24 @@ def tidy_up(fn):
 if sys.version_info[0] < 3:
     raise Exception("This runs with Python 3")
 
+try:
+    arg = sys.argv[1]
+except IndexError:
+    arg = ""
+if len(sys.argv) > 2 or not (arg == "" or arg == "-v" or arg == "-log" or arg == "-tex"):
+    print("One optional command line parameter is permitted:")
+    print(" python -m pyalmanac -v")
+    print(" ... to send pdfTeX output to the terminal")
+    print(" python -m pyalmanac -log")
+    print(" ... to keep the log file")
+    print(" python -m pyalmanac -tex")
+    print(" ... to keep the tex file")
+    sys.exit(0)
+
+args = "" if arg == "-v" else "-interaction=batchmode -halt-on-error "
+keeplog = True if arg == "-log" else False
+keeptex = True if arg == "-tex" else False
+
 d = datetime.datetime.utcnow().date()
 first_day = datetime.date(d.year, d.month, d.day)
 
@@ -164,7 +197,8 @@ if s in set(['1', '2', '3', '4', '5', '6', '7']):
             msg = "\nCreating the nautical almanac for the year {}\n".format(year)
             print(msg)
             first_day = datetime.date(yearint, 1, 1)
-            fn = "almanac{}{}".format(ff,year+DecFmt)
+            ff = "tradna_" if config.tbls != 'm' else "modna_"
+            fn = "{}{}".format(ff,year+DecFmt)
             outfile = open(fn + ".tex", mode="w", encoding="utf8")
             outfile.write(tables.almanac(first_day,122,dfA4N))
             outfile.close()
@@ -172,7 +206,7 @@ if s in set(['1', '2', '3', '4', '5', '6', '7']):
             msg = "execution time = {:0.2f} seconds".format(stop-start) # msg = "execution time = %0.2f seconds" %(stop-start)
             print(msg)
             print()
-            makePDF(fn, " creating nautical almanac for {}".format(year))
+            makePDF(args, fn, " creating nautical almanac for {}".format(year))
             tidy_up(fn)
 
     elif s == '2':      # Sun Tables (for a year)
@@ -181,11 +215,12 @@ if s in set(['1', '2', '3', '4', '5', '6', '7']):
             msg = "\nCreating the sun tables for the year {}\n".format(year)
             print(msg)
             first_day = datetime.date(yearint, 1, 1)
-            fn = "sunalmanac{}{}".format(ff,year+DecFmt)
+            ff = "tradst_" if config.tbls != 'm' else "modst_"
+            fn = "{}{}".format(ff,year+DecFmt)
             outfile = open(fn + ".tex", mode="w", encoding="utf8")
             outfile.write(suntables.almanac(first_day,25,dfra))
             outfile.close()
-            makePDF(fn, " creating sun tables for {}".format(year))
+            makePDF(args, fn, " creating sun tables for {}".format(year))
             tidy_up(fn)
 
     elif s == '3':      # Event Time tables  (for a year)
@@ -196,7 +231,7 @@ if s in set(['1', '2', '3', '4', '5', '6', '7']):
             msg = "\nCreating the event time tables for the year {}\n".format(year)
             print(msg)
             first_day = datetime.date(yearint, 1, 1)
-            fn = "event-times{}".format(year)
+            fn = "event-times_{}".format(year)
             outfile = open(fn + ".tex", mode="w", encoding="utf8")
             outfile.write(eventtables.maketables(first_day,183,dfA4N))
             outfile.close()
@@ -204,41 +239,43 @@ if s in set(['1', '2', '3', '4', '5', '6', '7']):
             msg = "execution time = {:0.2f} seconds".format(stop-start) # msg = "execution time = %0.2f seconds" %(stop-start)
             print(msg)
             print()
-            makePDF(fn, " creating event time tables for {}".format(year))
+            makePDF(args, fn, " creating event time tables for {}".format(year))
             tidy_up(fn)
 
     elif s == '4':      # Nautical almanac   -  6 days from today
 ##        config.initLOG()		# initialize log file
         msg = "\nCreating nautical almanac tables - from {}\n".format(sdmy)
         print(msg)
-        fn = "almanac{}{}".format(ff,symd+DecFmt)
+        ff = "tradna_" if config.tbls != 'm' else "modna_"
+        fn = "{}{}".format(ff,symd+DecFmt)
         outfile = open(fn + ".tex", mode="w", encoding="utf8")
         outfile.write(tables.almanac(first_day,2,dfA4N))
         outfile.close()
 ##        msg = 'Count of incorrect values: {}'.format(config.errors)
 ##        config.writeLOG('\n' + msg + '\n')
 ##        config.closeLOG()
-        makePDF(fn)
+        makePDF(args, fn)
         tidy_up(fn)
 
     elif s == '5':      # Sun tables only    - 30 days from today
         msg = "\nCreating the sun tables - from {}\n".format(sdmy)
         print(msg)
-        fn = "sunalmanac{}{}".format(ff,symd+DecFmt)
+        ff = "tradst_" if config.tbls != 'm' else "modst_"
+        fn = "{}{}".format(ff,symd+DecFmt)
         outfile = open(fn + ".tex", mode="w", encoding="utf8")
         outfile.write(suntables.almanac(first_day,2,dfra))
         outfile.close()
-        makePDF(fn)
+        makePDF(args, fn)
         tidy_up(fn)
 
     elif s == '6':      # Event Time tables  -  6 days from today
         msg = "\nCreating event time tables - from {}\n".format(sdmy)
         print(msg)
-        fn = "event-times{}".format(symd)
+        fn = "event-times_{}".format(symd)
         outfile = open(fn + ".tex", mode="w", encoding="utf8")
         outfile.write(eventtables.maketables(first_day,3,dfA4N))
         outfile.close()
-        makePDF(fn)
+        makePDF(args, fn)
         tidy_up(fn)
 
     elif s == '7':
@@ -248,7 +285,7 @@ if s in set(['1', '2', '3', '4', '5', '6', '7']):
         outfile = open(fn + ".tex", mode="w", encoding="utf8")
         outfile.write(increments.makelatex())
         outfile.close()
-        makePDF(fn)
+        makePDF(args, fn)
         tidy_up(fn)
 
 else:
